#!/bin/sh
cd ../common

for fn in *.c *.h; do
  echo Converting $fn to sjis...
  iconv -f EUCJP -t MS932 $fn -o $fn.new \
	&& mv $fn.new $fn \
	|| rm -f $fn.new
done

